# Cookbook:: Grafana
# Recipe:: default
#
# Copyright:: 2018, The Authors, All Rights Reserved.

case node['platform']
when 'centos'

#---------Adding Grafana Repository--------------------------- 
yum_repository 'GRAFANA_REPO' do
  description 'Grafana yum repository'
  url 'https://packagecloud.io/grafana/stable/el/7/$basearch'
  enabled true
  gpgcheck true
  gpgkey 'https://packagecloud.io/gpg.key  https://grafanarel.s3.amazonaws.com/RPM-GPG-KEY-grafana'
  action :create
end

#-------Updating Yum Repo-------------------------------------
execute "run-yum-clean-all" do
  command "sudo yum clean all"
end
execute "run-yum-update-" do
  command "sudo yum  update -y"
end

#---------Installing-Packages---------------------------------
package "grafana" do
  action :install
end

#---------Managing-Configurations----------------------------
directory '/var/lib/grafana/dashboards' do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

cookbook_file "/etc/grafana/provisioning/datasources/datasource.yaml" do
      source "datasource.yaml"
end

cookbook_file "/etc/grafana/provisioning/dashboards/dashboard.yaml" do
      source "dashboard.yaml"
end

cookbook_file "/var/lib/grafana/dashboards/Dashboard.json" do
      source "Dashboard.json"
end



#--------Restarting and Enabling Services---------------------
service "grafana-server" do
  action [:restart, :enable]
end



when 'ubuntu'

#-------Adding Grafana Repo for Ubuntu---------------------
apt_repository 'Grafana_Install' do
  uri	       'https://packagecloud.io/grafana/stable/debian/'
  distribution 'stretch'
  components   ['main']
  key          'https://packagecloud.io/gpg.key'
end


#------Updating The Repository---------------------------
apt_update 'update'


#------Installing Telegraf InfluxDb and Grafana----------
package "grafana" do
  action :install
end


#---------Managing COnfigurations-------------------------
directory '/var/lib/grafana/dashboards' do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

cookbook_file "/etc/grafana/provisioning/datasources/datasource.yaml" do
      source "datasource.yaml"
end


cookbook_file "/etc/grafana/provisioning/dashboards/dashboard.yaml" do
      source "dashboard.yaml"
end

cookbook_file "/var/lib/grafana/dashboards/Dashboard.json" do
      source "Dashboard.json"
end


#---------Restarting The Services-------------------------
service "grafana-server" do
  action [:restart, :enable]
end

end
